@@ -144,6 +144,36 @@ class EvalMetric:
                     total += 1
                 result = {"EM": em / (total or not total), "F1": f1 / (total or not total)}
                 data_score = sorted(data_score, key=lambda i: i[2]['em'], reverse=True)
+            if "er" in metric:
+                try:
+                    import asrp
+                except ImportError:
+                    print(
+                        "asrp package not install, plz install it: pip install asrp")
+                    raise
+                predicts = []
+                targets = []
+                for pos, predict in enumerate(task['predicted']):
+                    wer_list = []
+                    cer_list = []
+                    for target in task['target_list'][pos]:
+                        if len(target) > 0 and len(predict) > 0:
+                            wer_list.append(100 * asrp.chunked_wer([target], [predict]))
+                            cer_list.append(100 * asrp.chunked_cer([target], [predict]))
+                        else:
+                            wer_list.append(100)
+                            cer_list.append(100)
+                    wer = min(wer_list)
+                    cer = min(cer_list)
+                    target = task['target_list'][pos][wer_list.index(wer)]
+                    predicts.append(predict)
+                    targets.append(target)
+                    data_score.append([predict, target, {'wer': wer, 'cer': cer}])
+
+                wer = 100 * asrp.chunked_wer(targets, predicts, chunk_size=100) if len(target) > 0 else 100
+                cer = 100 * asrp.chunked_cer(targets, predicts, chunk_size=100) if len(target) > 0 else 100
+                result = {"WER": wer, "CER": cer}
+                data_score = sorted(data_score, key=lambda i: i[2]['wer'], reverse=False)
             if "nlg" in metric:
                 try:
                     from nlgeval import NLGEval
