@@ -48,7 +48,6 @@ class Predictor:
             previous = self.model.tokenizer.tokenize(input.split(tok.UNIVERSAL_SEP)[-1])
             eos_num += 1
 
-        self.model.eval()
         sequences = [[[], 1.0]]
         with torch.no_grad():
             while True:
@@ -72,7 +71,7 @@ class Predictor:
 
                         for k, v in feature_dict.items():
                             feature_dict[k] = [v]
-                        predictions = self.model.forward(feature_dict, eval=True, use_prev=True)
+                        predictions = self.model.forward(feature_dict, eval=True, use_prev=True,beamsearch=decodenum>1)
                         token_prob_list = predictions['label_prob_all'][0]
                         # topK topP
                         if 'top' in mode:
@@ -133,4 +132,5 @@ class Predictor:
                 'label_map': sequences
             }
             self.model.encoder_hidden = None
+            self.model.past_key_values = None
             return [i[0] for i in sequences], [result_dict]
